[svn:parrot] r49583 - trunk/src/gc

Util at svn.parrot.org Util at svn.parrot.org
Tue Oct 19 18:01:25 UTC 2010


Author: Util
Date: Tue Oct 19 18:01:24 2010
New Revision: 49583
URL: https://trac.parrot.org/parrot/changeset/49583

Log:
Reverting r49557 to resolve Rakudo abnormal build times

Modified:
   trunk/src/gc/gc_ms2.c

Modified: trunk/src/gc/gc_ms2.c
==============================================================================
--- trunk/src/gc/gc_ms2.c	Tue Oct 19 12:06:53 2010	(r49582)
+++ trunk/src/gc/gc_ms2.c	Tue Oct 19 18:01:24 2010	(r49583)
@@ -630,9 +630,9 @@
 
         self->fixed_size_allocator = Parrot_gc_fixed_allocator_new(interp);
 
         /* Collect every 16M allocated. */
         /* Hardcode for now. Will be configured via CLI */
-        self->gc_threshold = 16 * 1024 * 1024;
+        self->gc_threshold = 256 * 1024 * 1024;
     }
 
     interp->gc_sys->gc_private = self;
@@ -630,9 +630,9 @@
         self->fixed_size_allocator = Parrot_gc_fixed_allocator_new(interp);
 
-        /* Collect every 16M allocated. */
+        /* Collect every 256M allocated. */
         /* Hardcode for now. Will be configured via CLI */


More information about the parrot-commits mailing list